# PulpOstreeClient::ContentContentApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentContentApi.md#create) | **POST** /pulp/api/v3/content/ostree/content/ | Create an ostree content
[**list**](ContentContentApi.md#list) | **GET** /pulp/api/v3/content/ostree/content/ | List ostree contents
[**read**](ContentContentApi.md#read) | **GET** {ostree_ostree_content_href} | Inspect an ostree content



## create

> AsyncOperationResponse create(ostree_ostree_content)

Create an ostree content

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentContentApi.new
ostree_ostree_content = PulpOstreeClient::OstreeOstreeContent.new # OstreeOstreeContent | 

begin
  #Create an ostree content
  result = api_instance.create(ostree_ostree_content)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentContentApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_content** | [**OstreeOstreeContent**](OstreeOstreeContent.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginatedostreeOstreeContentResponseList list(opts)

List ostree contents

A ViewSet class for uncategorized content units (e.g., static deltas).

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentContentApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pk` - Pk * `-pk` - Pk (descending)
  orphaned_for: 3.4, # Float | Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List ostree contents
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentContentApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **orphaned_for** | **Float**| Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME. | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedostreeOstreeContentResponseList**](PaginatedostreeOstreeContentResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> OstreeOstreeContentResponse read(ostree_ostree_content_href, opts)

Inspect an ostree content

A ViewSet class for uncategorized content units (e.g., static deltas).

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::ContentContentApi.new
ostree_ostree_content_href = 'ostree_ostree_content_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an ostree content
  result = api_instance.read(ostree_ostree_content_href, opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling ContentContentApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_content_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**OstreeOstreeContentResponse**](OstreeOstreeContentResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

